function I = f_trade(x,mu,sigma,epsilon,f_e,f_d,tau,f_x)

% DESCRIPTION
% This function computes the free-entry condition in open economy under the
% assumption of lognormally-distributed productivity (equation A14, Appendix A)

% INPUTS:
% x: productivity cutoff for serving the domestic market under the trade regime
% mu, sigma: parameters of the (lognormal) productivity distribution
% epsilon: elasticity of substitution
% f_e: sunk entry costs
% f_d, f_x: fixed production and export costs
% tau: variable trade costs

% OUTPUT:
% I: value of the free entry condition

% USAGE: I = f_trade(x,mu,sigma,epsilon,f_e,f_d,tau,f_x);

% AUTHORS: Marco Bee, Department of Economics and Management, University of Trento; e-mail: marco.bee@unitn.it
%          Stefano Schiavo, School of International Studies and Department of Economics and Management, University of Trento and OFCE-DRIC; e-mail: stefano.schiavo@unitn.it
% This version: June 30, 2015

    cutoff = f_d/(tau^(epsilon-1)); 
    indici1 = find(f_x >= cutoff);
    indici2 = find(f_x <= cutoff);
        if x<=0
            x = 1e-20;
        end
    phix(indici1) = tau*(f_x(indici1)/f_d)^(1/(epsilon-1))*x;     
    phix(indici2) = x;
    a0 = (log(x)-mu)/sigma;
    a1 = (log(phix)-mu)/sigma;
    I1 = exp((epsilon-1)*mu+(epsilon-1)^2*sigma^2/2)*normcdf((epsilon-1)*sigma-a0)/normcdf(-a0);
    I2 = exp((epsilon-1)*mu+(epsilon-1)^2*sigma^2/2)*normcdf((epsilon-1)*sigma-a1)/normcdf(-a1);
    I = f_e - f_d*(1-logncdf(x,mu,sigma)) * (I1/x^(epsilon-1)-1) - f_x*(1-logncdf(phix,mu,sigma)) * (I2/phix^(epsilon-1)-1);  % (16) Melitz-Redding
end
